@@ -1,24 +1,7 @@
-# The MIT License (MIT)
+# SPDX-FileCopyrightText: 2018 Dean Miller for Adafruit Industries
 #
-# Copyright (c) 2018 Dean Miller for Adafruit Industries
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
+# SPDX-License-Identifier: MIT
+
 """
 `adafruit_epd.epd` - Adafruit EPD - ePaper display driver
 ====================================================================================
@@ -36,8 +19,7 @@ __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_EPD.git"
 
 
 class Adafruit_EPD:  # pylint: disable=too-many-instance-attributes, too-many-public-methods
-    """Base class for EPD displays
-    """
+    """Base class for EPD displays"""
 
     BLACK = const(0)
     WHITE = const(1)
@@ -209,7 +191,7 @@ class Adafruit_EPD:  # pylint: disable=too-many-instance-attributes, too-many-pu
 
     def power_up(self):
         """Power up the display in preparation for writing RAM and updating.
-         must be implemented in subclass"""
+        must be implemented in subclass"""
         raise NotImplementedError()
 
     def power_down(self):
